@@ -9,7 +9,7 @@ import sys
 
 import pytest
 import yaml
-from airbyte_cdk.sources.declarative.exceptions import InvalidConnectorDefinitionException
+from airbyte_cdk.sources.declarative.declarative_stream import DeclarativeStream
 from airbyte_cdk.sources.declarative.manifest_declarative_source import ManifestDeclarativeSource
 from jsonschema.exceptions import ValidationError
 
@@ -32,7 +32,7 @@ class MockManifestDeclarativeSource(ManifestDeclarativeSource):
     """
 
 
-class TestYamlDeclarativeSource:
+class TestManifestDeclarativeSource:
     @pytest.fixture
     def use_external_yaml_spec(self):
         # Our way of resolving the absolute path to root of the airbyte-cdk unit test directory where spec.yaml files should
@@ -50,7 +50,8 @@ class TestYamlDeclarativeSource:
         yield
         os.remove(yaml_path)
 
-    def test_valid_manifest(self):
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_valid_manifest(self, construct_using_pydantic_models):
         manifest = {
             "version": "version",
             "definitions": {
@@ -85,7 +86,11 @@ class TestYamlDeclarativeSource:
                             "page_size": 10,
                             "page_size_option": {"inject_into": "request_parameter", "field_name": "page_size"},
                             "page_token_option": {"inject_into": "path"},
-                            "pagination_strategy": {"type": "CursorPagination", "cursor_value": "{{ response._metadata.next }}"},
+                            "pagination_strategy": {
+                                "type": "CursorPagination",
+                                "cursor_value": "{{ response._metadata.next }}",
+                                "page_size": 10,
+                            },
                         },
                         "requester": {
                             "path": "/v3/marketing/lists",
@@ -108,7 +113,11 @@ class TestYamlDeclarativeSource:
                             "page_size": 10,
                             "page_size_option": {"inject_into": "request_parameter", "field_name": "page_size"},
                             "page_token_option": {"inject_into": "path"},
-                            "pagination_strategy": {"type": "CursorPagination", "cursor_value": "{{ response._metadata.next }}"},
+                            "pagination_strategy": {
+                                "type": "CursorPagination",
+                                "cursor_value": "{{ response._metadata.next }}",
+                                "page_size": 10,
+                            },
                         },
                         "requester": {
                             "type": "CustomRequester",
@@ -122,9 +131,18 @@ class TestYamlDeclarativeSource:
             ],
             "check": {"type": "CheckStream", "stream_names": ["lists"]},
         }
-        ManifestDeclarativeSource(source_config=manifest)
+        source = ManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
 
-    def test_manifest_with_spec(self):
+        check_stream = source.connection_checker
+        check_stream.check_connection(source, logging.getLogger(""), {})
+
+        streams = source.streams({})
+        assert len(streams) == 2
+        assert isinstance(streams[0], DeclarativeStream)
+        assert isinstance(streams[1], DeclarativeStream)
+
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_manifest_with_spec(self, construct_using_pydantic_models):
         manifest = {
             "version": "version",
             "definitions": {
@@ -185,7 +203,7 @@ class TestYamlDeclarativeSource:
                 },
             },
         }
-        source = ManifestDeclarativeSource(source_config=manifest)
+        source = ManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
         connector_specification = source.spec(logger)
         assert connector_specification is not None
         assert connector_specification.documentationUrl == "https://airbyte.com/#yaml-from-manifest"
@@ -200,7 +218,8 @@ class TestYamlDeclarativeSource:
             "order": 0,
         }
 
-    def test_manifest_with_external_spec(self, use_external_yaml_spec):
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_manifest_with_external_spec(self, use_external_yaml_spec, construct_using_pydantic_models):
         manifest = {
             "version": "version",
             "definitions": {
@@ -248,14 +267,15 @@ class TestYamlDeclarativeSource:
             ],
             "check": {"type": "CheckStream", "stream_names": ["lists"]},
         }
-        source = MockManifestDeclarativeSource(source_config=manifest)
+        source = MockManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
 
         connector_specification = source.spec(logger)
 
         assert connector_specification.documentationUrl == "https://airbyte.com/#yaml-from-external"
         assert connector_specification.connectionSpecification == EXTERNAL_CONNECTION_SPECIFICATION
 
-    def test_source_is_not_created_if_toplevel_fields_are_unknown(self):
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_source_is_not_created_if_toplevel_fields_are_unknown(self, construct_using_pydantic_models):
         manifest = {
             "version": "version",
             "definitions": {
@@ -304,10 +324,11 @@ class TestYamlDeclarativeSource:
             "check": {"type": "CheckStream", "stream_names": ["lists"]},
             "not_a_valid_field": "error",
         }
-        with pytest.raises(InvalidConnectorDefinitionException):
-            ManifestDeclarativeSource(manifest)
+        with pytest.raises(ValidationError):
+            ManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
 
-    def test_source_missing_checker_fails_validation(self):
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_source_missing_checker_fails_validation(self, construct_using_pydantic_models):
         manifest = {
             "version": "version",
             "definitions": {
@@ -356,14 +377,16 @@ class TestYamlDeclarativeSource:
             "check": {"type": "CheckStream"},
         }
         with pytest.raises(ValidationError):
-            ManifestDeclarativeSource(source_config=manifest)
+            ManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
 
-    def test_source_with_missing_streams_fails(self):
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_source_with_missing_streams_fails(self, construct_using_pydantic_models):
         manifest = {"version": "version", "definitions": None, "check": {"type": "CheckStream", "stream_names": ["lists"]}}
         with pytest.raises(ValidationError):
-            ManifestDeclarativeSource(manifest)
+            ManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
 
-    def test_source_with_missing_version_fails(self):
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_source_with_missing_version_fails(self, construct_using_pydantic_models):
         manifest = {
             "definitions": {
                 "schema_loader": {"name": "{{ options.stream_name }}", "file_path": "./source_sendgrid/schemas/{{ options.name }}.yaml"},
@@ -411,9 +434,10 @@ class TestYamlDeclarativeSource:
             "check": {"type": "CheckStream", "stream_names": ["lists"]},
         }
         with pytest.raises(ValidationError):
-            ManifestDeclarativeSource(manifest)
+            ManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
 
-    def test_source_with_invalid_stream_config_fails_validation(self):
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_source_with_invalid_stream_config_fails_validation(self, construct_using_pydantic_models):
         manifest = {
             "version": "version",
             "definitions": {
@@ -432,9 +456,10 @@ class TestYamlDeclarativeSource:
             "check": {"type": "CheckStream", "stream_names": ["lists"]},
         }
         with pytest.raises(ValidationError):
-            ManifestDeclarativeSource(manifest)
+            ManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
 
-    def test_source_with_no_external_spec_and_no_in_yaml_spec_fails(self):
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_source_with_no_external_spec_and_no_in_yaml_spec_fails(self, construct_using_pydantic_models):
         manifest = {
             "version": "version",
             "definitions": {
@@ -482,12 +507,40 @@ class TestYamlDeclarativeSource:
             ],
             "check": {"type": "CheckStream", "stream_names": ["lists"]},
         }
-        source = ManifestDeclarativeSource(source_config=manifest)
+        source = ManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
 
         # We expect to fail here because we have not created a temporary spec.yaml file
         with pytest.raises(FileNotFoundError):
             source.spec(logger)
 
+    @pytest.mark.parametrize("construct_using_pydantic_models", [True, False])
+    def test_manifest_without_at_least_one_stream(self, construct_using_pydantic_models):
+        manifest = {
+            "version": "version",
+            "definitions": {
+                "schema_loader": {"name": "{{ options.stream_name }}", "file_path": "./source_sendgrid/schemas/{{ options.name }}.yaml"},
+                "retriever": {
+                    "paginator": {
+                        "type": "DefaultPaginator",
+                        "page_size": 10,
+                        "page_size_option": {"inject_into": "request_parameter", "field_name": "page_size"},
+                        "page_token_option": {"inject_into": "path"},
+                        "pagination_strategy": {"type": "CursorPagination", "cursor_value": "{{ response._metadata.next }}"},
+                    },
+                    "requester": {
+                        "path": "/v3/marketing/lists",
+                        "authenticator": {"type": "BearerAuthenticator", "api_token": "{{ config.apikey }}"},
+                        "request_parameters": {"page_size": 10},
+                    },
+                    "record_selector": {"extractor": {"field_pointer": ["result"]}},
+                },
+            },
+            "streams": [],
+            "check": {"type": "CheckStream", "stream_names": ["lists"]},
+        }
+        with pytest.raises(ValidationError):
+            ManifestDeclarativeSource(source_config=manifest, construct_using_pydantic_models=construct_using_pydantic_models)
+
 
 def test_generate_schema():
     schema_str = ManifestDeclarativeSource.generate_schema()
