@@ -7,10 +7,10 @@ import logging
 import tempfile
 from collections import defaultdict
 from contextlib import nullcontext as does_not_raise
-from typing import Any, List, Mapping, MutableMapping, Optional, Tuple
-from unittest.mock import MagicMock
+from typing import Any, Iterable, List, Mapping, MutableMapping, Optional, Tuple
 
 import pytest
+import requests
 from airbyte_cdk.models import (
     AirbyteGlobalState,
     AirbyteStateBlob,
@@ -23,7 +23,9 @@ from airbyte_cdk.models import (
     Type,
 )
 from airbyte_cdk.sources import AbstractSource, Source
+from airbyte_cdk.sources.streams.availability_strategy import AvailabilityStrategy
 from airbyte_cdk.sources.streams.core import Stream
+from airbyte_cdk.sources.streams.http.availability_strategy import HttpAvailabilityStrategy
 from airbyte_cdk.sources.streams.http.http import HttpStream
 from airbyte_cdk.sources.utils.transform import TransformConfig, TypeTransformer
 from pydantic import ValidationError
@@ -43,10 +45,15 @@ class MockSource(Source):
 
 
 class MockAbstractSource(AbstractSource):
+    def __init__(self, streams: Optional[List[Stream]] = None):
+        self._streams = streams
+
     def check_connection(self, *args, **kwargs) -> Tuple[bool, Optional[Any]]:
         return True, ""
 
     def streams(self, *args, **kwargs) -> List[Stream]:
+        if self._streams:
+            return self._streams
         return []
 
 
@@ -79,26 +86,30 @@ def abstract_source(mocker):
     mocker.patch.multiple(HttpStream, __abstractmethods__=set())
     mocker.patch.multiple(Stream, __abstractmethods__=set())
 
-    class MockHttpStream(MagicMock, HttpStream):
+    class MockHttpStream(mocker.MagicMock, HttpStream):
         url_base = "http://example.com"
         path = "/dummy/path"
-        get_json_schema = MagicMock()
+        get_json_schema = mocker.MagicMock()
 
         def supports_incremental(self):
             return True
 
         def __init__(self, *args, **kvargs):
-            MagicMock.__init__(self)
+            mocker.MagicMock.__init__(self)
             HttpStream.__init__(self, *args, kvargs)
-            self.read_records = MagicMock()
+            self.read_records = mocker.MagicMock()
 
-    class MockStream(MagicMock, Stream):
+        @property
+        def availability_strategy(self):
+            return None
+
+    class MockStream(mocker.MagicMock, Stream):
         page_size = None
-        get_json_schema = MagicMock()
+        get_json_schema = mocker.MagicMock()
 
-        def __init__(self, *args, **kvargs):
-            MagicMock.__init__(self)
-            self.read_records = MagicMock()
+        def __init__(self, **kwargs):
+            mocker.MagicMock.__init__(self)
+            self.read_records = mocker.MagicMock()
 
     streams = [MockHttpStream(), MockStream()]
 
@@ -385,8 +396,8 @@ def test_internal_config(abstract_source, catalog):
     assert not non_http_stream.page_size
 
 
-def test_internal_config_limit(abstract_source, catalog):
-    logger_mock = MagicMock()
+def test_internal_config_limit(mocker, abstract_source, catalog):
+    logger_mock = mocker.MagicMock()
     logger_mock.level = logging.DEBUG
     del catalog.streams[1]
     STREAM_LIMIT = 2
@@ -423,8 +434,8 @@ def test_internal_config_limit(abstract_source, catalog):
 SCHEMA = {"type": "object", "properties": {"value": {"type": "string"}}}
 
 
-def test_source_config_no_transform(abstract_source, catalog):
-    logger_mock = MagicMock()
+def test_source_config_no_transform(mocker, abstract_source, catalog):
+    logger_mock = mocker.MagicMock()
     logger_mock.level = logging.DEBUG
     streams = abstract_source.streams(None)
     http_stream, non_http_stream = streams
@@ -437,8 +448,8 @@ def test_source_config_no_transform(abstract_source, catalog):
     assert non_http_stream.get_json_schema.call_count == 5
 
 
-def test_source_config_transform(abstract_source, catalog):
-    logger_mock = MagicMock()
+def test_source_config_transform(mocker, abstract_source, catalog):
+    logger_mock = mocker.MagicMock()
     logger_mock.level = logging.DEBUG
     streams = abstract_source.streams(None)
     http_stream, non_http_stream = streams
@@ -451,8 +462,8 @@ def test_source_config_transform(abstract_source, catalog):
     assert [r.record.data for r in records] == [{"value": "23"}] * 2
 
 
-def test_source_config_transform_and_no_transform(abstract_source, catalog):
-    logger_mock = MagicMock()
+def test_source_config_transform_and_no_transform(mocker, abstract_source, catalog):
+    logger_mock = mocker.MagicMock()
     logger_mock.level = logging.DEBUG
     streams = abstract_source.streams(None)
     http_stream, non_http_stream = streams
@@ -462,3 +473,126 @@ def test_source_config_transform_and_no_transform(abstract_source, catalog):
     records = [r for r in abstract_source.read(logger=logger_mock, config={}, catalog=catalog, state={})]
     assert len(records) == 2
     assert [r.record.data for r in records] == [{"value": "23"}, {"value": 23}]
+
+
+def test_read_default_http_availability_strategy_stream_available(catalog, mocker):
+    mocker.patch.multiple(HttpStream, __abstractmethods__=set())
+    mocker.patch.multiple(Stream, __abstractmethods__=set())
+
+    class MockHttpStream(mocker.MagicMock, HttpStream):
+        url_base = "http://example.com"
+        path = "/dummy/path"
+        get_json_schema = mocker.MagicMock()
+
+        def supports_incremental(self):
+            return True
+
+        def __init__(self, *args, **kvargs):
+            mocker.MagicMock.__init__(self)
+            HttpStream.__init__(self, *args, kvargs)
+            self.read_records = mocker.MagicMock()
+
+        # TODO (Ella): Remove explicit definition when turning on default
+        @property
+        def availability_strategy(self) -> Optional["AvailabilityStrategy"]:
+            return HttpAvailabilityStrategy()
+
+    class MockStream(mocker.MagicMock, Stream):
+        page_size = None
+        get_json_schema = mocker.MagicMock()
+
+        def __init__(self, *args, **kvargs):
+            mocker.MagicMock.__init__(self)
+            self.read_records = mocker.MagicMock()
+
+    streams = [MockHttpStream(), MockStream()]
+    http_stream, non_http_stream = streams
+    assert isinstance(http_stream, HttpStream)
+    assert not isinstance(non_http_stream, HttpStream)
+
+    assert isinstance(http_stream.availability_strategy, HttpAvailabilityStrategy)
+    assert non_http_stream.availability_strategy is None
+
+    # Add an extra record for the default HttpAvailabilityStrategy to pull from
+    # during the try: next(records) check, since we are mocking the return value
+    # and not re-creating the generator like we would during actual reading
+    http_stream.read_records.return_value = iter([{"value": "test"}] + [{}] * 3)
+    non_http_stream.read_records.return_value = iter([{}] * 3)
+
+    source = MockAbstractSource(streams=streams)
+    logger = logging.getLogger(f"airbyte.{getattr(abstract_source, 'name', '')}")
+    records = [r for r in source.read(logger=logger, config={}, catalog=catalog, state={})]
+    # 3 for http stream and 3 for non http stream
+    assert len(records) == 3 + 3
+    assert http_stream.read_records.called
+    assert non_http_stream.read_records.called
+
+
+def test_read_default_http_availability_strategy_stream_unavailable(catalog, mocker, caplog):
+    mocker.patch.multiple(Stream, __abstractmethods__=set())
+
+    class MockHttpStream(HttpStream):
+        url_base = "https://test_base_url.com"
+        primary_key = ""
+
+        def __init__(self, **kwargs):
+            super().__init__(**kwargs)
+            self.resp_counter = 1
+
+        def next_page_token(self, response: requests.Response) -> Optional[Mapping[str, Any]]:
+            return None
+
+        def path(self, **kwargs) -> str:
+            return ""
+
+        def parse_response(self, response: requests.Response, **kwargs) -> Iterable[Mapping]:
+            stub_response = {"data": self.resp_counter}
+            self.resp_counter += 1
+            yield stub_response
+
+        # TODO (Ella): Remove explicit definition when turning on default
+        @property
+        def availability_strategy(self) -> Optional["AvailabilityStrategy"]:
+            return HttpAvailabilityStrategy()
+
+    class MockStream(mocker.MagicMock, Stream):
+        page_size = None
+        get_json_schema = mocker.MagicMock()
+
+        def __init__(self, *args, **kvargs):
+            mocker.MagicMock.__init__(self)
+            self.read_records = mocker.MagicMock()
+
+    streams = [MockHttpStream(), MockStream()]
+    http_stream, non_http_stream = streams
+    assert isinstance(http_stream, HttpStream)
+    assert not isinstance(non_http_stream, HttpStream)
+
+    assert isinstance(http_stream.availability_strategy, HttpAvailabilityStrategy)
+    assert non_http_stream.availability_strategy is None
+
+    # Don't set anything for read_records return value for HttpStream, since
+    # it should be skipped due to the stream being unavailable
+    non_http_stream.read_records.return_value = iter([{}] * 3)
+
+    # Patch HTTP request to stream endpoint to make it unavailable
+    req = requests.Response()
+    req.status_code = 403
+    mocker.patch.object(requests.Session, "send", return_value=req)
+
+    source = MockAbstractSource(streams=streams)
+    logger = logging.getLogger("test_read_default_http_availability_strategy_stream_unavailable")
+    with caplog.at_level(logging.WARNING):
+        records = [r for r in source.read(logger=logger, config={}, catalog=catalog, state={})]
+
+    # 0 for http stream and 3 for non http stream
+    assert len(records) == 0 + 3
+    assert non_http_stream.read_records.called
+    expected_logs = [
+        f"Skipped syncing stream '{http_stream.name}' because it was unavailable.",
+        f"The endpoint to access stream '{http_stream.name}' returned 403: Forbidden.",
+        "This is most likely due to insufficient permissions on the credentials in use.",
+        f"Please visit https://docs.airbyte.com/integrations/sources/{source.name} to learn more."
+    ]
+    for message in expected_logs:
+        assert message in caplog.text
